Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
mcp_bridge/tools/__init__.py | 9 | 0 | 0 | 100%
mcp_bridge/tools/agent_manager.py | 363 | 108 | 1 | 70%
mcp_bridge/tools/background_tasks.py | 94 | 63 | 0 | 33%
mcp_bridge/tools/code_search.py | 170 | 161 | 0 | 5%
mcp_bridge/tools/continuous_loop.py | 33 | 27 | 0 | 18%
mcp_bridge/tools/init.py | 25 | 25 | 0 | 0%
mcp_bridge/tools/lsp/__init__.py | 3 | 3 | 0 | 0%
mcp_bridge/tools/lsp/manager.py | 215 | 215 | 0 | 0%
mcp_bridge/tools/lsp/tools.py | 445 | 445 | 0 | 0%
mcp_bridge/tools/model_invoke.py | 486 | 345 | 0 | 29%
mcp_bridge/tools/project_context.py | 69 | 69 | 0 | 0%
mcp_bridge/tools/query_classifier.py | 84 | 3 | 0 | 96%
mcp_bridge/tools/semantic_search.py | 1469 | 868 | 0 | 41%
mcp_bridge/tools/session_manager.py | 155 | 147 | 0 | 5%
mcp_bridge/tools/skill_loader.py | 83 | 75 | 0 | 10%
mcp_bridge/tools/task_runner.py | 66 | 66 | 0 | 0%
mcp_bridge/tools/templates.py | 10 | 10 | 0 | 0%
Total | 3779 | 2630 | 1 | 30%

No items found using the specified filter.